pub fn parse_usage(spec: &ProviderSpec, text: &str) -> Option<u64>Expand description
Pull a token count out of provider output using its configured regex.
pub fn parse_usage(spec: &ProviderSpec, text: &str) -> Option<u64>Pull a token count out of provider output using its configured regex.